var searchData=
[
  ['main_20loop_0',['Main Loop',['../group__pw__main__loop.html',1,'']]],
  ['main_2dloop_2eh_1',['main-loop.h',['../main-loop_8h.html',1,'']]],
  ['making_20a_20connection_2',['Making a connection',['../page_native_protocol.html#native-protocol-making-connection',1,'']]],
  ['manager_3',['Manager',['../page_session_manager.html',1,'PipeWire Session Manager'],['../group__pw__session__manager.html',1,'Session Manager'],['../page_module_session_manager.html',1,'Session Manager']]],
  ['manager_4',['Netjack2 manager',['../page_module_netjack2_manager.html',1,'page_modules']]],
  ['manager_20properties_5',['Session Manager Properties',['../page_man_pipewire-client_conf_5.html#client_conf__session_manager_properties',1,'']]],
  ['map_6',['Map',['../group__pw__map.html',1,'']]],
  ['map_7',['map',['../structpw__memblock.html#ae9876a344086ff407cf6bf3704b24515',1,'pw_memblock']]],
  ['map_2eh_8',['map.h',['../map_8h.html',1,'']]],
  ['mapoffset_9',['mapoffset',['../structspa__data.html#a75b63dcf6ea09c5908b8682f1696eeae',1,'spa_data']]],
  ['mask_10',['mask',['../structspa__source.html#ad43d6b5fd83f3e86be4f6103009370cd',1,'spa_source']]],
  ['match_20rules_11',['MATCH RULES',['../page_man_pipewire_conf_5.html#pipewire_conf__match_rules',1,'MATCH RULES'],['../page_man_pipewire-jack_conf_5.html#jack_conf__match_rules',1,'MATCH RULES']]],
  ['matrix_12',['matrix',['../structspa__video__colorimetry.html#aa2b220b0a2586562f3547505f851fd21',1,'spa_video_colorimetry']]],
  ['max_13',['max',['../structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1',1,'pw_stream_control::max'],['../structspa__io__latency.html#a5f23744c90a1dc0e9f0c1e067b8d390a',1,'spa_io_latency::max']]],
  ['max_5falign_14',['max_align',['../structspa__buffer__alloc__info.html#a51af051b079634c3f854680f118716e7',1,'spa_buffer_alloc_info']]],
  ['max_5fframerate_15',['max_framerate',['../structspa__video__info__h264.html#af680ca708a6fac71a3236cb73e1e1fc1',1,'spa_video_info_h264::max_framerate'],['../structspa__video__info__mjpg.html#a79a7bc729e3b98faa7285d6475b9867b',1,'spa_video_info_mjpg::max_framerate'],['../structspa__video__info__raw.html#af59a82989f29004917bb4f62b003addb',1,'spa_video_info_raw::max_framerate']]],
  ['max_5finput_5fports_16',['max_input_ports',['../structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e',1,'pw_node_info::max_input_ports'],['../structspa__node__info.html#a9f05f762157f2ae9db446937f19da173',1,'spa_node_info::max_input_ports']]],
  ['max_5fns_17',['max_ns',['../structspa__latency__info.html#ae4923a45e4de7d99b8aa658c4e59235e',1,'spa_latency_info']]],
  ['max_5foutput_5fports_18',['max_output_ports',['../structpw__node__info.html#ac312e1844784e77e412f6bb341814372',1,'pw_node_info::max_output_ports'],['../structspa__node__info.html#a5c181a5c275e9a0c9ec82156a38f10a5',1,'spa_node_info::max_output_ports']]],
  ['max_5fquantum_19',['max_quantum',['../structspa__latency__info.html#aab5617769d3799f99a80747917268db8',1,'spa_latency_info']]],
  ['max_5frate_20',['max_rate',['../structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec',1,'spa_latency_info']]],
  ['max_5fsize_21',['max_size',['../structspa__io__range.html#adac0f561e72d269206216a3327720ff7',1,'spa_io_range']]],
  ['max_5fvalues_22',['max_values',['../structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046',1,'pw_stream_control']]],
  ['maxsize_23',['maxsize',['../structspa__data.html#ae942ee4f53c1ae2b708fdea5aa334406',1,'spa_data::maxsize'],['../structspa__strbuf.html#ac82fdbc33669185a77140a3faf908a0c',1,'spa_strbuf::maxsize']]],
  ['media_5fclass_24',['media_class',['../structpw__endpoint__info.html#ac9c79172b3c9d4a42d622896d357eb4a',1,'pw_endpoint_info']]],
  ['media_5fsubtype_25',['media_subtype',['../structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75',1,'spa_audio_info::media_subtype'],['../structspa__video__info.html#a429e55f4dde148559d032bcaf8cd73f0',1,'spa_video_info::media_subtype']]],
  ['media_5ftype_26',['media_type',['../structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30',1,'spa_audio_info::media_type'],['../structspa__video__info.html#a73d52ad69db77b05afa52a8cb61455c9',1,'spa_video_info::media_type']]],
  ['mem_27',['mem',['../structpw__buffers.html#af915317f3448e471390a13c48c0d873e',1,'pw_buffers']]],
  ['mem_2eh_28',['mem.h',['../spa_2include_2spa_2debug_2mem_8h.html',1,'(Global Namespace)'],['../src_2pipewire_2mem_8h.html',1,'(Global Namespace)']]],
  ['mem_5fid_29',['mem_id',['../structpw__client__node__buffer.html#a0b4e8dbf6a9aad4e72153fd2bf5f6392',1,'pw_client_node_buffer']]],
  ['mem_5fsize_30',['mem_size',['../structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6',1,'spa_buffer_alloc_info']]],
  ['memory_20blocks_31',['Memory Blocks',['../group__pw__memblock.html',1,'']]],
  ['message_32',['message',['../structspa__result__node__error.html#a396020ed7279b7f3293cc2c2eec47485',1,'spa_result_node_error']]],
  ['message_20header_33',['Message header',['../page_native_protocol.html#native-protocol-message-header',1,'']]],
  ['meta_2eh_34',['meta.h',['../meta_8h.html',1,'']]],
  ['meta_5fsize_35',['meta_size',['../structspa__buffer__alloc__info.html#a63296028aeb53c2e98501c78f1d53617',1,'spa_buffer_alloc_info']]],
  ['metadata_36',['Metadata',['../group__pw__metadata.html',1,'Metadata'],['../page_module_metadata.html',1,'Metadata']]],
  ['metadata_37',['pw-metadata',['../page_man_pw-metadata_1.html',1,'page_programs']]],
  ['metadata_20impl_38',['Metadata Impl',['../group__pw__impl__metadata.html',1,'']]],
  ['metadata_2eh_39',['metadata.h',['../metadata_8h.html',1,'']]],
  ['metas_40',['metas',['../structspa__buffer__alloc__info.html#aef6e15022383cf49cbba4196111c190d',1,'spa_buffer_alloc_info::metas'],['../structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e',1,'spa_buffer::metas']]],
  ['methods_41',['Methods',['../page_proxy.html#sec_page_proxy_methods',1,'']]],
  ['midi_20support_42',['MIDI Support',['../page_midi.html',1,'page_internals']]],
  ['mididump_43',['pw-mididump',['../page_man_pw-mididump_1.html',1,'page_programs']]],
  ['min_44',['min',['../structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62',1,'pw_stream_control::min'],['../structspa__io__latency.html#a017f13089f0f6847cd70e62d725bd99c',1,'spa_io_latency::min']]],
  ['min_5fns_45',['min_ns',['../structspa__latency__info.html#ac9e3498891f63e0c2f6e6df171febb5b',1,'spa_latency_info']]],
  ['min_5fquantum_46',['min_quantum',['../structspa__latency__info.html#aadaa9a123ffe5f4a050945e210cc5725',1,'spa_latency_info']]],
  ['min_5frate_47',['min_rate',['../structspa__latency__info.html#a114447a982c76675818ca5fff6e5b101',1,'spa_latency_info']]],
  ['min_5fsize_48',['min_size',['../structspa__io__range.html#af3d7c25e34fd60458e8ca8cfa1067c92',1,'spa_io_range']]],
  ['minutes_49',['minutes',['../structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db',1,'spa_io_segment_video']]],
  ['miscellaneous_50',['Miscellaneous',['../group__spa__utils__defs.html',1,'']]],
  ['mjpg_51',['mjpg',['../structspa__video__info.html#a0e442291121d1e295e2db47ead38eb11',1,'spa_video_info']]],
  ['mjpg_2dutils_2eh_52',['mjpg-utils.h',['../mjpg-utils_8h.html',1,'']]],
  ['mjpg_2eh_53',['mjpg.h',['../mjpg_8h.html',1,'']]],
  ['modifier_54',['modifier',['../structspa__video__info__dsp.html#af38a7a5f53d475331ebf38a12994566c',1,'spa_video_info_dsp::modifier'],['../structspa__video__info__raw.html#a72e94aea5e8202b5a114af286c22a269',1,'spa_video_info_raw::modifier']]],
  ['module_55',['Module',['../group__pw__module.html',1,'']]],
  ['module_20impl_56',['Module Impl',['../group__pw__impl__module.html',1,'']]],
  ['module_2eh_57',['module.h',['../module_8h.html',1,'']]],
  ['modules_58',['MODULES',['../page_man_pipewire_conf_5.html#pipewire_conf__modules',1,'MODULES'],['../page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_modules',1,'PULSEAUDIO MODULES']]],
  ['modules_59',['Modules',['../page_modules.html',1,'Modules'],['../page_pulse_modules.html',1,'Pulseaudio Modules']]],
  ['modules_60',['modules',['../page_man_libpipewire-modules_7.html',1,'libpipewire-modules'],['../page_man_pipewire-pulse-modules_7.html',1,'pipewire-pulse-modules']]],
  ['mon_61',['pw-mon',['../page_man_pw-mon_1.html',1,'page_programs']]],
  ['monitor_62',['spa-monitor',['../page_man_spa-monitor_1.html',1,'page_programs']]],
  ['mp3_63',['mp3',['../structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b',1,'spa_audio_info']]],
  ['mp3_2dutils_2eh_64',['mp3-utils.h',['../mp3-utils_8h.html',1,'']]],
  ['multiview_2eh_65',['multiview.h',['../multiview_8h.html',1,'']]],
  ['multiview_5fflags_66',['multiview_flags',['../structspa__video__info__raw.html#a99a7b7e3ccd534510cb33036028edd7e',1,'spa_video_info_raw']]],
  ['multiview_5fmode_67',['multiview_mode',['../structspa__video__info__raw.html#a48a1b5480465ffdcee2dfa9e95ed47fb',1,'spa_video_info_raw']]]
];
